<!DOCTYPE TS><TS>
<context>
    <name>DatabaseBox</name>
    <message>
        <source>Select music to be played:</source>
        <translation type="obsolete">Seleziona il brano musicale da ascoltare:</translation>
    </message>
    <message>
        <source>Copy To New Playlist</source>
        <translation>Copia in una nuova Playlist</translation>
    </message>
    <message>
        <source>Clear the Active Play Queue</source>
        <translation>Cancella la Play Queue attiva</translation>
    </message>
    <message>
        <source>Save Back to Playlist Tree</source>
        <translation>Salva nella Playlist</translation>
    </message>
    <message>
        <source>Move to Active Play Queue</source>
        <translation>Sposta nella Play Queue attiva</translation>
    </message>
    <message>
        <source>Delete This Playlist</source>
        <translation>Cancella questa Playlist</translation>
    </message>
    <message>
        <source>Rename This Playlist</source>
        <translation>Rinomina questa Playlist</translation>
    </message>
    <message>
        <source>Active Play Queue</source>
        <translation>Play Queue Attiva</translation>
    </message>
    <message>
        <source>All My Playlists</source>
        <translation>Tutte le mie Playlist</translation>
    </message>
    <message>
        <source>All My Music</source>
        <translation>La mia musica</translation>
    </message>
    <message>
        <source>Blechy Blech Blah</source>
        <translation>Blechy Blech Blah</translation>
    </message>
    <message>
        <source>All My Music ~ Loading Music Data </source>
        <translation>Tutta la mia musica ~ caricamento dei dati musicali</translation>
    </message>
    <message>
        <source>Loading Music Data</source>
        <translation>Caricamento dei dati musicali</translation>
    </message>
    <message>
        <source>The theme you are using does not contain a &apos;musictree&apos; element.  Please contact the theme creator and ask if they could please update it.&lt;br&gt;&lt;br&gt;The next screen will be empty.  Escape out of it to return to the menu.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Couldn&apos;t create CD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CD Created</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CD-RW Blanking Progress</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Create Audio CD from Playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Create MP3 CD from Playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear CD-RW Disk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The theme you are using does not contain any info lines in the music element.  Please contact the theme creator and ask if they could please update it.&lt;br&gt;&lt;br&gt;The next screen will be empty.  Escape out of it to return to the menu.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Artist:<byte value="x9"/></source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Album:<byte value="x9"/></source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title:<byte value="x9"/></source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Length:<byte value="x9"/></source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Genre: </source>
        <translation type="unfinished">Genere:</translation>
    </message>
    <message>
        <source>Compilation Artist:<byte value="x9"/></source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditMetadataDialog</name>
    <message>
        <source>Done</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DB Statistics</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Various Artists</source>
        <translation type="unfinished">Artisti Vari</translation>
    </message>
    <message>
        <source>Select an Artist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select a Compilation Artist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select an Album</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select a Genre</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save Changes?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save to Database Only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save to File Only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save to File and Database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exit/Do Not Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to save the modified metadata to the file?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PlaybackBox</name>
    <message>
        <source>Edit Playlist</source>
        <translation type="obsolete">Modifica la Playlist</translation>
    </message>
    <message>
        <source>Visualize</source>
        <translation type="obsolete">Visualizza</translation>
    </message>
    <message>
        <source>Repeat: Track</source>
        <translation type="obsolete">Ripetizione: Traccia</translation>
    </message>
    <message>
        <source>Repeat: All</source>
        <translation type="obsolete">Ripetizione: Tutto</translation>
    </message>
    <message>
        <source>Playing stream.</source>
        <translation type="obsolete">Esecuzione brano.</translation>
    </message>
    <message>
        <source>Buffering stream.</source>
        <translation type="obsolete">Buffering del brano.</translation>
    </message>
    <message>
        <source>Stream paused.</source>
        <translation type="obsolete">Brano in pausa.</translation>
    </message>
    <message>
        <source>Output error.</source>
        <translation type="obsolete">Errore di Output.</translation>
    </message>
    <message>
        <source>Stream stopped.</source>
        <translation type="obsolete">Brano fermato.</translation>
    </message>
    <message>
        <source>Finished playing stream.</source>
        <translation type="obsolete">Esecuzione terminata.</translation>
    </message>
    <message>
        <source>Decoder error.</source>
        <translation type="obsolete">Errore di decodifica.</translation>
    </message>
    <message>
        <source>1 Shuffle: None</source>
        <translation type="obsolete">1 Ordine: No</translation>
    </message>
    <message>
        <source>Shuffle: None</source>
        <translation type="obsolete">Ordine: No</translation>
    </message>
    <message>
        <source>2 Repeat: All</source>
        <translation type="obsolete">2 Ripeti: Tutti</translation>
    </message>
    <message>
        <source>2 Repeat: Track</source>
        <translation type="obsolete">2 Ripeti: Traccia</translation>
    </message>
    <message>
        <source>2 Repeat: None</source>
        <translation type="obsolete">2 Ripeti: No</translation>
    </message>
    <message>
        <source>Repeat: None</source>
        <translation type="obsolete">Ripeti: No</translation>
    </message>
    <message>
        <source>3 Edit Playlist</source>
        <translation type="obsolete">3 Modifica Playlist</translation>
    </message>
    <message>
        <source>4 Visualize</source>
        <translation type="obsolete">4 Visualizza</translation>
    </message>
    <message>
        <source>1 Shuffle: Smart</source>
        <translation type="obsolete">1 Ordine: Furbo</translation>
    </message>
    <message>
        <source>Shuffle: Smart</source>
        <translation type="obsolete">Ordine: Furbo</translation>
    </message>
    <message>
        <source>1 Shuffle: Rand</source>
        <translation type="obsolete">1 Ordine: Casuale</translation>
    </message>
    <message>
        <source>Shuffle: Rand</source>
        <translation type="obsolete">Ordine: Casuale</translation>
    </message>
    <message>
        <source>playlist root</source>
        <translation type="obsolete">Radice della Playlist</translation>
    </message>
    <message>
        <source>kbps</source>
        <translation type="obsolete">kbps</translation>
    </message>
    <message>
        <source>kHz</source>
        <translation type="obsolete">kHz</translation>
    </message>
    <message>
        <source>ch</source>
        <translation type="obsolete">ch</translation>
    </message>
</context>
<context>
    <name>PlaybackBoxMusic</name>
    <message>
        <source>Edit Playlist</source>
        <translation type="unfinished">Modifica la Playlist</translation>
    </message>
    <message>
        <source>Visualize</source>
        <translation type="unfinished">Visualizza</translation>
    </message>
    <message>
        <source>3 Edit Playlist</source>
        <translation type="unfinished">3 Modifica Playlist</translation>
    </message>
    <message>
        <source>4 Visualize</source>
        <translation type="unfinished">4 Visualizza</translation>
    </message>
    <message>
        <source>1 Shuffle: Smart</source>
        <translation type="unfinished">1 Ordine: Furbo</translation>
    </message>
    <message>
        <source>Shuffle: Smart</source>
        <translation type="unfinished">Ordine: Furbo</translation>
    </message>
    <message>
        <source>1 Shuffle: Rand</source>
        <translation type="unfinished">1 Ordine: Casuale</translation>
    </message>
    <message>
        <source>Shuffle: Rand</source>
        <translation type="unfinished">Ordine: Casuale</translation>
    </message>
    <message>
        <source>1 Shuffle: None</source>
        <translation type="unfinished">1 Ordine: No</translation>
    </message>
    <message>
        <source>Shuffle: None</source>
        <translation type="unfinished">Ordine: No</translation>
    </message>
    <message>
        <source>2 Repeat: All</source>
        <translation type="unfinished">2 Ripeti: Tutti</translation>
    </message>
    <message>
        <source>Repeat: All</source>
        <translation type="unfinished">Ripetizione: Tutto</translation>
    </message>
    <message>
        <source>2 Repeat: Track</source>
        <translation type="unfinished">2 Ripeti: Traccia</translation>
    </message>
    <message>
        <source>Repeat: Track</source>
        <translation type="unfinished">Ripetizione: Traccia</translation>
    </message>
    <message>
        <source>2 Repeat: None</source>
        <translation type="unfinished">2 Ripeti: No</translation>
    </message>
    <message>
        <source>Repeat: None</source>
        <translation type="unfinished">Ripeti: No</translation>
    </message>
    <message>
        <source>playlist root</source>
        <translation type="unfinished">Radice della Playlist</translation>
    </message>
    <message>
        <source>Playing stream.</source>
        <translation type="unfinished">Esecuzione brano.</translation>
    </message>
    <message>
        <source>Buffering stream.</source>
        <translation type="unfinished">Buffering del brano.</translation>
    </message>
    <message>
        <source>Stream paused.</source>
        <translation type="unfinished">Brano in pausa.</translation>
    </message>
    <message>
        <source>kbps</source>
        <translation type="unfinished">kbps</translation>
    </message>
    <message>
        <source>kHz</source>
        <translation type="unfinished">kHz</translation>
    </message>
    <message>
        <source>ch</source>
        <translation type="unfinished">ch</translation>
    </message>
    <message>
        <source>Output error.</source>
        <translation type="unfinished">Errore di Output.</translation>
    </message>
    <message>
        <source>Stream stopped.</source>
        <translation type="unfinished">Brano fermato.</translation>
    </message>
    <message>
        <source>Finished playing stream.</source>
        <translation type="unfinished">Esecuzione terminata.</translation>
    </message>
    <message>
        <source>Decoder error.</source>
        <translation type="unfinished">Errore di decodifica.</translation>
    </message>
    <message>
        <source>Smart playlists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Tracks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tracks by current Artist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tracks from current Album</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tracks from current Genre</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tracks from current Year</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Searching for music files</source>
        <translation>Ricerca dei file musicali</translation>
    </message>
    <message>
        <source>Updating music database</source>
        <translation>Aggiornamento del database musicale</translation>
    </message>
    <message>
        <source>BumpScope</source>
        <translation>BumpScope</translation>
    </message>
    <message>
        <source>Various Artists</source>
        <translation>Artisti Vari</translation>
    </message>
    <message>
        <source>Ogg Vorbis Audio</source>
        <translation>Audio Ogg Vorbis</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Sconosciuto</translation>
    </message>
    <message>
        <source>FLAC Audio</source>
        <translation>Audio FLAC</translation>
    </message>
    <message>
        <source>Directory to hold music</source>
        <translation>Cartella che contiene i file musicali</translation>
    </message>
    <message>
        <source>This directory must exist, and the user running MythMusic needs to have write permission to the directory.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio Device used for playback.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CD device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CDRom device used for ripping/playback.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tree Sorting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Script Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If present this script will be executed after a CD Rip is completed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filename Format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Directory and filename Format used to grab information if no ID3 information is found.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ignore ID3 Tags</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, MythMusic will skip checking ID3 tags in files and just try to determine Genre, Artist, Album, and Track number and title from the filename.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Automatically lookup CDs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Automatically lookup an audio CD if it is present and show its information in the Music Selection Tree.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use Keyboard/Remote Accelerated Buttons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If this is not set, you will need to use arrow keys to select and activate various functions.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Encoding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ogg Vorbis</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lame (MP3)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio encoder to use for CD ripping. Note that the quality level &apos;Perfect&apos; will use the FLAC encoder.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File storage location</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Defines the location/name for new songs. Valid tokens are: GENRE, ARTIST, ALBUM, TRACK, TITLE, YEAR, / and -. &apos;-&apos; will be replaced by the Token separator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Token separator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> - </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filename tokens will be separated by this string.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Replace &apos; &apos; with &apos;_&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, whitespace characters in filenames will be replaced with underscore characters.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paranoia Level</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Full</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Faster</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paranoia level of the CD ripper. Set to faster if you&apos;re not concerned about possible errors in the audio.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Automatically eject CDs after ripping</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, the CD tray will automatically open after the CD has been ripped.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rating Weight</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Used in &quot;Smart&quot; Shuffle mode. This weighting affects how much strength is given to your rating of a given track when ordering a group of songs.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play Count Weight</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Used in &quot;Smart&quot; Shuffle mode. This weighting affects how much strength is given to how many times a given track has been played when ordering a group of songs.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Last Play Weight</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Used in &quot;Smart&quot; Shuffle mode. This weighting affects how much strength is given to how long it has been since a given track was played when ordering a group of songs.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Random Weight</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Used in &quot;Smart&quot; Shuffle mode. This weighting affects how much strength is given to good old (peudo-)randomness when ordering a group of songs.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Song Ratings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show song ratings on the playback screen.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>List as Shuffled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>List songs on the playback screen in the order they will be played.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show entire music tree</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If selected, you can navigate your entire music tree from the playing screen.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Normal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Random</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Intelligent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Starting shuffle mode for the player.  Can be either normal, random, or intelligent (random).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delay before Visualizations start (seconds)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set to 0, visualizations will never automatically start.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change Visualizer on each song</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change the visualizer when the song change.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Width for Visual Scaling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set to &quot;2&quot;, visualizations will be scaled in half.  Currently only used by the goom visualization.  Reduces CPU load on slower machines.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Height for Visual Scaling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Visualizations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>List of visualizations to use during playback. Possible values are space-separated list of </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MonoScope</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>StereoScope</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Spectrum</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Goom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Synaesthesia</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gears</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Blank</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default Rip Quality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Low</source>
        <translation type="unfinished">Bassa</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation type="unfinished">Media</translation>
    </message>
    <message>
        <source>High</source>
        <translation type="unfinished">Alta</translation>
    </message>
    <message>
        <source>Perfect</source>
        <translation type="unfinished">Perfetto</translation>
    </message>
    <message>
        <source>Default quality for new CD rips.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>General Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Playback Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Visualization Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CD Ripper Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MPEG Layer 1/2/3 Audio (MAD decoder)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown Artist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown Album</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown Genre</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CD -- none</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All My Music</source>
        <translation type="unfinished">La mia musica</translation>
    </message>
    <message>
        <source>%1 - %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Missing database entry: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> ~ </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ooops</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 ~ %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Not Initialized</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>oops</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>,%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All My Playlists</source>
        <translation type="unfinished">Tutte le mie Playlist</translation>
    </message>
    <message>
        <source>Active Play Queue</source>
        <translation type="unfinished">Play Queue Attiva</translation>
    </message>
    <message>
        <source>Active Play Queue (%1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Something is Wrong</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Visualization requires FFT library</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Did you run configure?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>and</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use variable bitrates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, the MP3 encoder will use variable bitrates (VBR) except for the low quality setting. The Ogg encoder will always use variable bitrates.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AlbumArt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CD Ripper Settings (part 2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable CD Writing.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Requires a SCSI or an IDE-SCSI CD Writer.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CD-Writer Device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select the SCSI Device for CD Writing.  If your IDE device is not present, try adding hdd(or hdc/hdb)=ide-scsi to your boot options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disk Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>650MB/75min</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>700MB/80min</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default CD Capacity.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable directories on MP3 Creation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CD Write Speed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>4x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>8x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>16x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CD Writer speed. Auto will use the recomended speed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CD Blanking Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fast</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Complete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Blanking Method. Fast takes 1 minute. Complete can take up to 20 minutes.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CD Recording Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Artists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Creating CD File System</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Burning CD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Order in which to sort the Music Tree. Possible values are a space-separated list of genre, splitartist, artist, album, and title OR the keyword &quot;directory&quot; to indicate that the onscreen tree mirrors the filesystem.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CD: %1 ~ %2 - %3</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Ripper</name>
    <message>
        <source>Please select a quality level and check the album information below:</source>
        <translation>Seleziona la qualità e verifica le informazioni dell&apos;album</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Bassa</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Media</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Alta</translation>
    </message>
    <message>
        <source>Perfect</source>
        <translation>Perfetto</translation>
    </message>
    <message>
        <source>Artist: </source>
        <translation>Artista: </translation>
    </message>
    <message>
        <source>Album: </source>
        <translation>Album: </translation>
    </message>
    <message>
        <source>Import this CD</source>
        <translation>Importa questo CD</translation>
    </message>
    <message>
        <source>Importing CD:
</source>
        <translation>Importazione CD:
</translation>
    </message>
    <message>
        <source>Copying from CD:
</source>
        <translation>Copia da CD:
</translation>
    </message>
    <message>
        <source>Genre: </source>
        <translation>Genere:</translation>
    </message>
    <message>
        <source>Ripping...</source>
        <translation>Ripping...</translation>
    </message>
    <message>
        <source>Multi-Artist?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch Titles &amp;&amp; Artists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Artist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SmartPLCriteriaRow</name>
    <message>
        <source>Select an Artist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select an Album</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select a Genre</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select a Title</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SmartPLOrderByDialog</name>
    <message>
        <source>Order By Fields</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2 Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>3 Move Up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move Up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>4 Move Down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move Down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>5 Ascending</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ascending</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>6 Descending</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Descending</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>7 OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SmartPLResultViewer</name>
    <message>
        <source>Smart Playlist Result Viewer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Artist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Album</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Genre</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Year</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Track No.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SmartPlaylistDialog</name>
    <message>
        <source>Smart Playlists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 Select</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2 New</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>3 Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>4 Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete this SmartPlaylist?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SmartPlaylistEditor</name>
    <message>
        <source>Smart Playlist Editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Category:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Match</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Any</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Of The Following Conditions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Order By:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Matches:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Limit:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source></source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Results</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Smart Playlist Categories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New Category</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete Category</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename Category</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete this Category?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>It will also delete any Smart Playlists belonging to this category.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ThemeUI</name>
    <message>
        <source>Please Wait...</source>
        <translation>Attendere Prego...</translation>
    </message>
    <message>
        <source>Track Information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Artist:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Album:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Genre:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Year:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Track No.:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rating:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play Count:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Last Play:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Compilation:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filename:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
